@@ -1,10 +1,10 @@
+from ._napping_application import NappingApplication
+from ._napping_exception import NappingException
+from ._napping_navigator import NappingNavigator
+
 try:
     from ._version import version as __version__
 except ImportError:
     __version__ = "unknown"
 
-from napping._napping_application import NappingApplication
-from napping._napping_exception import NappingException
-from napping._napping_navigator import NappingNavigator
-
 __all__ = ["NappingApplication", "NappingException", "NappingNavigator"]
